@@ -47,10 +47,10 @@ if __name__ == '__main__':
 
     # Store in a given folder the HasTraits entity
     PATH = "."
-    h5.store_complete(conn_ht, PATH)
+    h5.store_complete_to_dir(conn_ht, PATH)
 
     # Reproduce the just written file name containing GUID
-    file_name = h5.path_for(PATH, ConnectivityH5, conn_ht.gid)
+    file_name = h5.path_by_dir(PATH, ConnectivityH5, conn_ht.gid)
 
     # Load back from a file name a HasTraits instance
     conn_back = h5.load(file_name)
